@@ -5,6 +5,11 @@ from django.forms import *
 
 
 class CommonFormMixin(Form):
+    """常用表单基类
+
+    显示一个提交按钮
+    """
+
     submit_button_name = '提交'
 
     def __init__(self, *args, **kwargs):
